@@ -39,7 +39,7 @@ class UnknownModelError(Exception):
 
 class ResultRetrievalError(Exception):
     def __init__(self):
-        msg = f"Failed to retrieve simulation results, could not read output files."
+        msg = 'Failed to retrieve simulation results, could not read output files.'
         Exception.__init__(self, msg)
 
 
@@ -83,7 +83,7 @@ def parse_error_string_simulate(out_string: str, terminate_on_assert: str = 'err
     _find_assert = re.compile(r'assert\s*\|\s*(\w+)\s*\|', re.IGNORECASE)
     _asserts = _find_assert.findall(out_string)
 
-    _assertion_ranking = ('info', 'warning', 'error', 'never')
+    _assertion_ranking = ('debug', 'info', 'warning', 'error', 'never')
 
     if not _asserts:
         return
